@@ -22,4 +22,4 @@ sub ping {
     1;
 }
 
-1;
+'beer';
